// Select DOM elements
const input = document.getElementById("task-input");
const addBtn = document.getElementById("add-task");
const list = document.getElementById("todo-list");
const showAll = document.getElementById("show-all");
const showActive = document.getElementById("show-active");
const showCompleted = document.getElementById("show-completed");
const clearCompleted = document.getElementById("clear-completed");

// Load from localStorage
let todos = JSON.parse(localStorage.getItem("todos")) || [];

// Render tasks
function renderTodos(filter = "all") {
    list.innerHTML = "";
    todos.forEach((todo, index) => {
        if (
        (filter === "active" && todo.completed) ||
        (filter === "completed" && !todo.completed)
        ) return;

        const li = document.createElement("li");
        li.className = todo.completed ? "completed" : "";
        li.innerHTML = `
        <span>${todo.text}</span>
        <div>
            <button onclick="toggleComplete(${index})">✔️</button>
            <button onclick="deleteTodo(${index})">🗑️</button>
        </div>
        `;
        list.appendChild(li);
    });
}

// Add new task
addBtn.addEventListener("click", () => {
    const text = input.value.trim();
    if (text !== "") {
        todos.push({ text, completed: false });
        input.value = "";
        saveAndRender();
    }
});

// Mark task as complete/incomplete
function toggleComplete(index) {
    todos[index].completed = !todos[index].completed;
    saveAndRender();
}

// Delete task
function deleteTodo(index) {
    todos.splice(index, 1);
    saveAndRender();
}

// Save to localStorage and re-render
function saveAndRender() {
    localStorage.setItem("todos", JSON.stringify(todos));
    renderTodos(currentFilter);
}

// Filters
let currentFilter = "all";
showAll.addEventListener("click", () => {
    currentFilter = "all";
    renderTodos("all");
});
showActive.addEventListener("click", () => {
    currentFilter = "active";
    renderTodos("active");
});
showCompleted.addEventListener("click", () => {
    currentFilter = "completed";
    renderTodos("completed");
});
clearCompleted.addEventListener("click", () => {
    todos = todos.filter(todo => !todo.completed);
    saveAndRender();
});

// Initial load
renderTodos();
